**PLUGINS**
===========

EXODUS
------
Train feedforward architectures much faster. `Github repository <https://github.com/synsense/sinabs-exodus>`_ 

Sinabs-DynapCNN
---------------
Deploy your model to state-of-the-art neuromrophic hardware. Documentation `available here. <https://synsense.gitlab.io/sinabs-dynapcnn/>`_